summaryrefslogtreecommitdiffstats
path: root/sound/soc/samsung/s3c-i2s-v2.h
diff options
context:
space:
mode:
authorKuninori Morimoto <kuninori.morimoto.gx@renesas.com>2013-03-21 03:35:22 -0700
committerMark Brown <broonie@opensource.wolfsonmicro.com>2013-03-26 21:57:31 +0000
commiteca3b01d0885544cbf452c5298afd7c3ccb53a50 (patch)
tree9c5756f6cc9e2a85dfc4192962be48896753ea51 /sound/soc/samsung/s3c-i2s-v2.h
parent5642ddff274172b42bb9d1f77b75e006a33b65b2 (diff)
downloadlinux-stable-eca3b01d0885544cbf452c5298afd7c3ccb53a50.tar.gz
linux-stable-eca3b01d0885544cbf452c5298afd7c3ccb53a50.tar.bz2
linux-stable-eca3b01d0885544cbf452c5298afd7c3ccb53a50.zip
ASoC: switch over to use snd_soc_register_component() on s3c i2s
Signed-off-by: Kuninori Morimoto <kuninori.morimoto.gx@renesas.com> Signed-off-by: Mark Brown <broonie@opensource.wolfsonmicro.com>
Diffstat (limited to 'sound/soc/samsung/s3c-i2s-v2.h')
-rw-r--r--sound/soc/samsung/s3c-i2s-v2.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/sound/soc/samsung/s3c-i2s-v2.h b/sound/soc/samsung/s3c-i2s-v2.h
index f8297d9bb8a3..90abab364b49 100644
--- a/sound/soc/samsung/s3c-i2s-v2.h
+++ b/sound/soc/samsung/s3c-i2s-v2.h
@@ -92,7 +92,7 @@ extern int s3c_i2sv2_probe(struct snd_soc_dai *dai,
unsigned long base);
/**
* s3c_i2sv2_register_dai - register dai with soc core
* @dev: DAI device
* @id: DAI ID
* @drv: The driver structure to register
@@ -100,7 +100,8 @@ extern int s3c_i2sv2_probe(struct snd_soc_dai *dai,
* Fill in any missing fields and then register the given dai with the
* soc core.
*/
-extern int s3c_i2sv2_register_dai(struct device *dev, int id,
- struct snd_soc_dai_driver *drv);
+extern int s3c_i2sv2_register_component(struct device *dev, int id,
+ struct snd_soc_component_driver *cmp_drv,
+ struct snd_soc_dai_driver *dai_drv);
#endif /* __SND_SOC_S3C24XX_S3C_I2SV2_I2S_H */
@@ -92,7 +92,7 @@ extern int s3c_i2sv2_probe(struct snd_soc_dai *dai,
unsigned long base);
/**
- * s3c_i2sv2_register_dai - register dai with soc core
+ * s3c_i2sv2_register_component - register component and dai with soc core
* @dev: DAI device
* @id: DAI ID